# Orchd SDK
Welcome to the **Orchd SDK** repository, it holds the basics mechanisms
and classes used by Orchd. It also offers the orchd-sdk CLI, it will help
you with boilerplate code generation and project management making it 
easy to create Orchd Extensions.

> This Software is released under the MIT License, check the license file (LICENSE.md)

## Installation

To install it, run:

```
pip install orchd-sdk
```

## Documentation

For detailed information about the latest version of `orchd-sdk` check
its official documentation at:

- [Orchd SDK Official Documentation](https://orchd-sdk.readthedocs.io/)

Maybe you would like also to check `Orchd` documentation at:

- [Orchd Official Documentation](https://orchd-sdk.readthedocs.io/)

Also make sure to go through the Architecture page of the documentation:

- [Orchd Official Documentation: Architecure](https://orchd-sdk.readthedocs.io/)


## Sponsors

This project is part of Mathias Santos de Brito's Ph.D. work and was partially/fully
sponsored/supported by:

- Technische Universität Berlin - Berlin/Germany
- Universidade Estadual de Santa Cruz (UESC) - Ilhéus/Brazil
- Conselho Nacional de Desenvolvimento Científico e Tecnológico (CNPq)
- Fraunhofer Institute FOKUS - Berlin/Germany
